Security Advisories (1)
CVE-2025-40909 (2025-05-30)

Perl threads have a working directory race condition where file operations may target unintended paths. If a directory handle is open at thread creation, the process-wide current working directory is temporarily changed in order to clone that handle for the new thread, which is visible from any third (or more) thread already running. This may lead to unintended operations such as loading code or accessing files from unexpected locations, which a local attacker may be able to exploit. The bug was introduced in commit 11a11ecf4bea72b17d250cfb43c897be1341861e and released in Perl version 5.13.6

USAGE

# generate the module changes for the Perl you are currently building
./perl -Ilib Porting/corelist-perldelta.pl

# update the module changes for the Perl you are currently building
./perl -Ilib Porting/corelist-perldelta.pl --mode=update pod/perldelta.pod

# generate a diff between the corelist sections of two perldelta* files:
perl Porting/corelist-perldelta.pl --mode=check 5.017001 5.017002 <perl5172delta.pod

ABOUT

corelist-perldelta.pl is a bit schizophrenic. The part to generate the new Perldelta text does not need Algorithm::Diff, but wants to be run with the freshly built Perl.

The part to check the diff wants to be run with a Perl that has an up-to-date Module::CoreList, but needs the outside Algorithm::Diff.

Ideally, the program will be split into two separate programs, one to generate the text and one to show the diff between the corelist sections of the last perldelta and the next perldelta.

Currently no information about Removed Modules is displayed in any of the modes.